summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorbriaguya <briaguya@alice>2022-09-29 23:57:19 -0400
committerlouist103 <35883445+louist103@users.noreply.github.com>2022-10-01 13:46:58 -0400
commit9804035dc013d505b0ef13ae3a56310be816b1fc (patch)
tree9f8a538d791d905b71cde593307ff1a02a18c7dd
parent973ec52b2a90ed46970a0d4dd88985306963c6a4 (diff)
fix: match auto center option text to behavior
-rw-r--r--soh/soh/Enhancements/controls/GameControlEditor.cpp2
-rw-r--r--soh/soh/GameMenuBar.cpp4
-rw-r--r--soh/src/overlays/actors/ovl_player_actor/z_player.c2
3 files changed, 4 insertions, 4 deletions
diff --git a/soh/soh/Enhancements/controls/GameControlEditor.cpp b/soh/soh/Enhancements/controls/GameControlEditor.cpp
index a2ec4f209..e2eccab8b 100644
--- a/soh/soh/Enhancements/controls/GameControlEditor.cpp
+++ b/soh/soh/Enhancements/controls/GameControlEditor.cpp
@@ -238,7 +238,7 @@ namespace GameControlEditor {
UIWidgets::PaddedEnhancementCheckbox("Right Stick Aiming", "gRightStickAiming");
UIWidgets::Tooltip("Allows for aiming with the rights stick when:\n-Aiming in the C-Up view\n-Aiming with weapons");
ImGui::SetCursorPosX(ImGui::GetCursorPosX() + 5);
- UIWidgets::PaddedEnhancementCheckbox("Disable Auto-Centering in First Person View", "gAutoCenterView");
+ UIWidgets::PaddedEnhancementCheckbox("Disable Auto-Centering in First Person View", "gDisableAutoCenterView");
UIWidgets::Tooltip("Prevents the C-Up view from auto-centering, allowing for Gyro Aiming");
}
diff --git a/soh/src/overlays/actors/ovl_player_actor/z_player.c b/soh/src/overlays/actors/ovl_player_actor/z_player.c
index 1a0877373..ed7ad12bf 100644
--- a/soh/src/overlays/actors/ovl_player_actor/z_player.c
+++ b/soh/src/overlays/actors/ovl_player_actor/z_player.c
@@ -11175,7 +11175,7 @@ s16 func_8084ABD8(GlobalContext* globalCtx, Player* this, s32 arg2, s16 arg3) {
s16 temp3;
if (!func_8002DD78(this) && !func_808334B4(this) && (arg2 == 0)) {
- if (CVar_GetS32("gAutoCenterView", 0)) {
+ if (!CVar_GetS32("gDisableAutoCenterView", 0)) {
temp2 = sControlInput->rel.stick_y * 240.0f * (CVar_GetS32("gInvertYAxis", 1) ? -1 : 1);
Math_SmoothStepToS(&this->actor.focus.rot.x, temp2, 14, 4000, 30);
diff --git a/soh/soh/GameMenuBar.cpp b/soh/soh/GameMenuBar.cpp
index 3be689c4d..c74ac8f17 100644
--- a/soh/soh/GameMenuBar.cpp
+++ b/soh/soh/GameMenuBar.cpp
@@ -117,8 +117,8 @@ namespace GameMenuBar {
CVar_SetS32("gInvertYAxis", 1);
// Right Stick Aiming
CVar_SetS32("gRightStickAiming", 0);
- // Auto-Center First Person View
- CVar_SetS32("gAutoCenterView", 0);
+ // Disable Auto-Center First Person View
+ CVar_SetS32("gDisableAutoCenterView", 0);
// Text Speed (1 to 5)
CVar_SetS32("gTextSpeed", 1);